<?php
/*
Plugin Name: Gigs Calendar
Plugin URI: http://blogsforbands.com
Description: A calendar to let musicians and other performing artists share their performance dates with their adoring public.
Author: Dan Coulter
Version: 0.2
Author URI: http://dancoulter.com
*/

$include_folder = dirname(__FILE__);
require_once $include_folder . '/version.php';


if ( defined('ABSPATH') ) :
	class dtc_gigs {
		function add_admin_page() {
			add_management_page('Gigs Calendar', 'Gigs Calendar', 7, 'gigs', array("dtc_gigs", "generate_admin_page"));
		}
		
		function admin_css() {
			$folder = get_bloginfo('wpurl') . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/';
			?>
				<link type="text/css" rel="stylesheet" href="<?php echo $folder; ?>jquery-calendar.css" />
				<link type="text/css" rel="stylesheet" href="<?php echo $folder; ?>gigs-calendar-admin.css" />
			<?php
		}
		
		function display_css() {
			$folder = get_bloginfo('wpurl') . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/';
			?>
				<link type="text/css" rel="stylesheet" href="<?php echo $folder; ?>gigs-calendar-display.css" />
			<?php
		}

		function generate_admin_page() {
			if ( isset($_GET['ladyhawke']) ) {
				update_option("gig_db_version", $_GET['ladyhawke']);
				dtc_gigs::upgrade();
			}
			
			$folder = get_bloginfo('wpurl') . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/';
			$pages = array(
				'Gigs' => 'gigs',
				'Archive' => 'archive',
				'Venues' => 'venues',
				'Settings' => 'settings',
				'Feedback/Bugs' => 'feedback',
				'Credits' => 'credits',
			);
			$options = get_option('gigs-calendar');
			?>
				<script type="text/javascript">
					var ajaxTarget = "<?php echo $folder; ?>";
					var nonce = "<?php echo wp_create_nonce(); ?>";
					var pageTarget = "";
				</script>
				<div class="wrap">
					<h2>Gigs Calendar</h2>
					<ul id="gigs-menu">
						<?php if ( !$options || empty($options['parent']) ) : ?>
							<li id="settings-tab">Settings</li>
						<?php else: ?>
							<?php foreach ( $pages as $displayName => $pageName ) : ?>
								<li id="<?php echo $pageName; ?>-tab"><?php echo $displayName; ?></li>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
					<div id="gigs-wrapper" class="wrap">
						<div id="loading">
							Loading...<br />
							<img src="<?php echo $folder; ?>images/ajax-loader.gif" alt="" />
						</div>
						<?php foreach ( $pages as $pageName ) : ?>
							<div id="<?php echo $pageName; ?>" class="gigs-page"></div>
						<?php endforeach; ?>
					</div>
				</div>
				<script type="text/javascript">
					jQuery(document).ready(function(){
						gigs_page_load(jQuery("#gigs-menu li").eq(0).attr("id").split("-")[0]);
					});
					
					jQuery("#gigs-menu li").click(function(){
						gigs_page_load(this.id.split("-")[0]);
					});
					
					gigs_page_load = function(page, query) {
						if ( query == undefined ) query = "";
						else query = "?" + query;
						
						try{pageDestroy();}catch(e){};
						jQuery("#loading").show();
						jQuery(".gigs-page:visible").hide();
						jQuery("#gigs-menu li.selected").removeClass("selected");
						jQuery("#" + page + "-tab").addClass("selected");
						pageTarget = ajaxTarget + page +'.ajax.php';
						jQuery("#" + page).load(pageTarget + query, {
							action:"load", 
							"page":page,
							"nonce":nonce
						}, function(){
							jQuery("#loading").hide();
							jQuery(".gigs-page:visible").hide();
							jQuery("#" + page).show();
						});
					}
					
					resetTableColors = function(table) {
						rows = jQuery(table).find("tbody tr");
						for ( i = 0; i < rows.length; i++ ) {
							if ( Math.floor(i/2) % 2 ) {
								rows.eq(i).removeClass("alternate");
							} else {
								rows.eq(i).addClass("alternate");
							}
						}
					}
					
				</script>
			<?php
		}
		
		function display($x){
			global $wpdb, $post, $include_folder;
			$options = get_option("gigs-calendar");
			require_once $include_folder . '/classes.php';
			$out = '';
			$is_archive = false;
			
			if ( $post->ID == $options['parent'] || $post->ID == $options['archive'] ) {
				if ( $post->ID == $options['archive'] ) $is_archive = true;
				$folder = get_bloginfo('wpurl') . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/';
				$g = new gig();
				if ( $is_archive ) {
					$g->search("date <= CURDATE()", "date DESC");
				} else {
					$g->search("date >= CURDATE()", "date ASC");
				}
				if ( $g->_count ) {
					$out .= '<table class="gigs"><tbody>';
					while ( $g->fetch() ) {
						$v = $g->getVenue(); 
						$p = $g->getPerformances(); 
						$p->fetch();
						$fields = array();
						$out .= '<tr class="gig upcoming gig-' . $g->id . '" id="gig-' . $g->id . '">';
							$fields['eventName'] = '<td class="eventName" valign="top">' . $g->eventName . '</td>';
							$fields['city'] = '<td class="city" valign="top">' . $v->getCity() . '</td>';
							$fields['venue'] = '<td class="venue" valign="top">' . $v->name . '</td>';
							$fields['date'] = '<td class="date" valign="top">' . dtcGigs::dateFormat($g->date) . '</td>';
							$fields['time'] = '<td class="time" valign="top">' . ($p->_count ? date("g:ia", strtotime($p->time)) : '') . '</td>';
							$fields['shortNotes'] = '<td class="shortNotes" valign="top">' . ($p->_count ? $p->shortNotes : '') . '</td>';
							if ( $is_archive ) {
								$fields['tickets'] = '';
							} else {
								$fields['tickets'] = '<td class="tickets icon" valign="top">' . (!empty($p->link) ? '<a target="_blank" href="' . $p->link . '"><img alt="Buy Tickets" title="Buy Tickets" class="clickable tickets" src="' . $folder . 'images/money_dollar.png" /></a>' : '') . '</td>';
							}
							$fields['map'] = '<td class="map icon" valign="top">' . ($v ? '<a target="_blank" href="' . $v->getMapLink() . '"><img alt="Map" title="Map" class="clickable map" src="' . $folder . 'images/world.png" /></a>' : '') . '</td>';
							
							$fields[$options['gig-link-field']] = str_replace(
								array('valign="top">', '</td>'),
								array('valign="top"><a href="' . $g->getPermalink() . '">', '</a>'),
								$fields[$options['gig-link-field']]
							);
							
							if ( isset($options['gigs-table-show']) && !empty($options['gigs-table-show']) ) {
								foreach ( $options['gigs-table-show'] as $f ) {
									$out .= $fields[$f];
								}
							} else {
								$out .= implode($fields);
							}
						$out .= '</tr>';
						while ( $p->fetch() ) {
							$out .= '<tr class="performance upcoming gig-' . $g->id . '" id="performance-<?php echo $p->id ?>">';
								$fields['eventName'] = '<td class="eventName" valign="top"></td>';
								$fields['city'] = '<td class="city" valign="top"></td>';
								$fields['venue'] = '<td class="venue" valign="top"></td>';
								$fields['date'] = '<td class="date" valign="top"></td>';
								$fields['time'] = '<td class="time" valign="top">' . date("g:ia", strtotime($p->time)). '</td>';
								$fields['shortNotes'] = '<td class="shortNotes" valign="top">' . $p->shortNotes . '</td>';
								$fields['tickets'] = '<td class="tickets icon" valign="top">' . (!empty($p->link) ? '<a target="_blank" href="' . $p->link . '"><img alt="Buy Tickets" title="Buy Tickets" class="clickable tickets" src="' . $folder . 'images/money_dollar.png" /></a>' : '') . '</td>';
								$fields['map'] = '<td class="map icon" valign="top"></td>';
								if ( isset($options['gigs-table-show']) && !empty($options['gigs-table-show']) ) {
									foreach ( $options['gigs-table-show'] as $f ) {
										$out .= $fields[$f];
									}
								} else {
									$out .= implode($fields);
								}
							$out .= '</tr>';
						}
					}
					$out .= '</tbody></table>';
				} else {
					if ( $is_archive ) {
						$out .= '<div class="no-gigs">' . $options['no-past'] . '</div>';
					} else {
						$out .= '<div class="no-gigs">' . $options['no-upcoming'] . '</div>';
					}
				}
				$out .= '<div class="attribution">';
				if ( $options['b4b-link'] ) {
					$out .= '<span class="b4b">Powered by <a target="_blank" href="http://blogsforbands.com">Blogs for Bands</a></span>';
				}
				if ( $options['silk-link'] ) {
					$out .= '<span class="silk">Silk icons by <a target="_blank" href="http://www.famfamfam.com/lab/icons/silk/">Mark James</a></span>';
				}
				$out .= '</div>';
				
				if ( $options['rss-link'] ) {
					//$out .= '<div class="gigs-rss"><a href="' . get_bloginfo('wpurl') . '/?feed=rss2&cat=' . $options['category'] . '">Subscribe to the feed <img src="' . $folder . 'images/feed-icon.png" alt="RSS" title="RSS" /></a></div>';
				}

				
				$out = '<div><div>' . $x . '</div><div>' . $out . '</div></div>';
			} else {
				$g = new gig();
				if ( $g->getByPostID($post->ID) ) {
					$folder = get_bloginfo('wpurl') . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/';
					$v = $g->getVenue();
					$p = $g->getPerformances();
					$out .= '<div class="gig gig-post" id="gig-' . $g->id . '"><table><tbody>';
						if ( !empty($g->eventName) ) {
							$out .= '<tr class="' . dtcGigs::generateSlug($options['eventName-label']) . '">';
								$out .= '<td class="bold" valign="top">' . $options['eventName-label'] . '</td>';
								$out .= '<td>';
									$out .= '<div class="eventName">' . $g->eventName . '</div>';
								$out .= '</td>';
							$out .= '</tr>';

						}
						$out .= '<tr class="when">';
							$out .= '<td class="bold" valign="top">When</td>';
							$out .= '<td>';
								$out .= '<div class="date">' . dtcGigs::dateFormat($g->date, false) . '</div>';
								while (	$p->fetch() ) {
									$out .= '<div class="performance">';
										$out .= '<span class="time">' . date("g:ia", strtotime($p->time)) . '</span>';
										if ( !empty($p->shortNotes) ) {
											$out .= ' <span class="separator shortNotes">-</span> ';
											$out .= '<span class="shortNotes">' . $p->shortNotes . '</span>';
										}
										$out .= ' <span class="separator ages">-</span> ';
										$out .= '<span class="ages">' . $p->ages . '</span>';
										if ( !empty($p->link) ) {
											$out .= '<a href="' . $p->link . '"><img class="buy" src="' . $folder . 'images/money_dollar.png" alt="Buy Tickets" title="Buy Tickets" /></a>';
										}
									$out .= '</div>';
								}
							$out .= '</td>';
						$out .= '</tr>';
						$out .= '<tr class="where">';
							$out .= '<td class="bold" valign="top">Where</td>';
							$out .= '<td class="venue">';
								if ( $v->private ) {
									$out .= '<div class="name">Private Venue</div>';
								} else {
									$out .= '<div class="name">';
									if ( !empty($v->link) ) {
										$out .= '<a href="' . $v->link . '">' . $v->name . '</a>';
									} else {
										$out .= $v->name;
									}
									$out .= ' (<a href="' . $v->getMapLink() . '">map</a>)</div>';
									$out .= '<div class="address">' . nl2br($v->getAddress()) . '</div>';
									if ( !empty($v->notes) ) {
										$out .= '<p class="notes">' . nl2br($v->notes) . '</p>';
									}
								}
							$out .= '</td>';
						$out .= '</tr>';
						if ( !empty($g->notes) ) {
							$out .= '<tr class="other"><td class="bold" valign="top">Other Info</td><td>' . nl2br($g->notes) . '</td></tr>';
						}
					$out .= '</tbody></table></div>';
					$out .= '<p>&laquo; <a href="' . get_permalink($options['parent']) . '">Back to the calendar</a></p>';
									
					$out = '<div><div>' . $x . '</div><div>' . $out . '</div></div>';
				} else {
					return $x;
				}
			}
			return $out;
		}

		function upgrade() {
			global $wpdb;
			
			if ( isset($wpdb->charset) ) {
				$charset = $wpdb->charset;
			} else {
				$charset = DB_CHARSET;
			}
			
			$queries = array(
				array( // 1
					'
						CREATE TABLE `' . $wpdb->prefix . 'gigs_venue` (
							`id` INT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY ,
							`name` VARCHAR( 255 ) NOT NULL ,
							`address` TEXT NOT NULL ,
							`city` VARCHAR( 255 ) NOT NULL ,
							`state` VARCHAR( 255 ) NOT NULL ,
							`country` VARCHAR( 255 ) NOT NULL ,
							`postalCode` VARCHAR( 255 ) NOT NULL ,
							`contact` VARCHAR( 255 ) NOT NULL ,
							`phone` VARCHAR( 255 ) NOT NULL ,
							`email` VARCHAR( 255 ) NOT NULL ,
							`link` VARCHAR( 255 ) NOT NULL ,
							`notes` TEXT NOT NULL ,
							`private` TINYINT NOT NULL ,
							`apiID` INT UNSIGNED NOT NULL ,
							`deleted` TINYINT NOT NULL
						) ENGINE = MYISAM DEFAULT CHARSET=' . $charset . '
					', '
						CREATE TABLE `' . $wpdb->prefix . 'gigs_gig` (
							`id` INT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY ,
							`venueID` INT UNSIGNED NOT NULL ,
							`date` DATE NOT NULL ,
							`notes` TEXT NOT NULL,
							`postID` BIGINT UNSIGNED NOT NULL
						) ENGINE = MYISAM DEFAULT CHARSET=' . $charset . '
					', '
						CREATE TABLE `' . $wpdb->prefix . 'gigs_performance` (
							`id` INT UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY ,
							`gigID` INT UNSIGNED NOT NULL ,
							`time` TIME NULL ,
							`link` VARCHAR( 255 ) NOT NULL ,
							`shortNotes` VARCHAR( 255 ) NOT NULL ,
							`ages` VARCHAR( 255 ) NOT NULL
						) ENGINE = MYISAM DEFAULT CHARSET=' . $charset . '
					'
				), array( // 2
					'ALTER TABLE `' . $wpdb->prefix . 'gigs_venue` ADD `customMap` VARCHAR( 255 ) NOT NULL',
					'ALTER TABLE `' . $wpdb->prefix . 'gigs_gig` ADD `eventName` VARCHAR( 255 ) NOT NULL',
				),
			);
			for ( $i = (int) get_option('gig_db_version'); $i < (int) DTC_GIGS_DB_VERSION; $i++) {
				foreach ( $queries[$i] as $q ) {
					$wpdb->query($q);
				}
			}
			
			update_option("gig_db_version", (int) DTC_GIGS_DB_VERSION);
		}
		
		
		function hide_posts($where) {
			global $wp_the_query;
			global $wp_query;
			global $wpdb;
			
			$o = get_option('gigs-calendar');

			if ( $wp_the_query->is_single ) {
				return $where;
			} elseif ( !is_single() && (!is_category() || $wp_the_query->query_vars['cat'] != $o['category']) && !defined('gigs-query-mod')) {
				$where .= ' AND ID NOT IN (SELECT postID FROM ' . $wpdb->prefix . 'gigs_gig)';
			} elseif ( is_category() && $wp_the_query->query_vars['cat'] == $o['category'] ) {
				$where = str_replace(
					"(post_status = 'publish' OR post_status = 'private')", 
					"(post_status = 'publish' OR post_status = 'private' OR post_status='future')", 
					$where
				);
			}
			return $where;
		}
		
		
		function post_nav($where) {
			global $wp_the_query, $include_folder, $wpdb, $wp_version;
			
			include_once $include_folder . '/classes.php';
			
			$wtq = $wp_the_query;
			$g = new gig();
			
			$table = ''; // This will let me support versions < 2.3
			if ( $wp_version >= 2.3 ) {
				$table = 'p.';
			}
			
			if ( $wtq->is_single && $wpdb->get_var('SELECT COUNT(*) FROM ' . $wpdb->prefix . 'gigs_gig WHERE postID = ' . $wtq->post->ID) ) { // Is a gig
				$where .= ' AND ' . $table . 'ID IN (SELECT postID FROM ' . $wpdb->prefix . 'gigs_gig)';
				$where = str_replace(
					$table . "post_status = 'publish'", 
					"(". $table . "post_status = 'publish' OR ". $table . "post_status='future')", 
					$where
				);

			} else {
				$where .= ' AND ' . $table . 'ID NOT IN (SELECT postID FROM ' . $wpdb->prefix . 'gigs_gig)';
			}			
			return $where;
		}
		
		function widget_upcoming($args) {
			extract($args);
			$o = get_option('gigs-calendar');
			if ( !isset($o['widget']['upcoming']) ) $o['widget']['upcoming'] = array();
			?>
				<?php echo $before_widget; ?>
				<?php echo $before_title . $o['widget']['upcoming']['title'] . $after_title; ?>
					<?php dtc_gigs::upcomingList($o['widget']['upcoming']); ?>
				<?php echo $after_widget; ?>
			<?php
		}
		
		function widget_upcoming_control() {
			$o = get_option('gigs-calendar');
			if ( !isset($o['widget']['upcoming']) ) {
				$o['widget']['upcoming'] = array();
				$o['widget']['upcoming']['title'] = 'Upcoming Gigs';
				$o['widget']['upcoming']['length'] = 5;
				$o['widget']['upcoming']['dateFormat'] = 'M j';
				$o['widget']['upcoming']['dateFormatYear'] = 'M j, Y';
				$o['widget']['upcoming']['link'] = array();
				$o['widget']['upcoming']['link'][] = 'city';
				$o['widget']['upcoming']['link'][] = 'none';
			}
			
			if ( isset($_POST['gigs_length']) ) {
				$o['widget']['upcoming']['title'] = isset($_POST['gigs_title']) ? $_POST['gigs_title'] : $o['widget']['upcoming']['title'];
				$o['widget']['upcoming']['length'] = !empty($_POST['gigs_length']) ? $_POST['gigs_length'] : 5;
				$o['widget']['upcoming']['dateFormat'] = !empty($_POST['gigs_dateFormat']) ? $_POST['gigs_dateFormat'] : 'M j';
				$o['widget']['upcoming']['dateFormatYear'] = !empty($_POST['gigs_dateFormatYear']) ? $_POST['gigs_dateFormatYear'] : 'M j, Y';
				$o['widget']['upcoming']['link'] = array();
				$o['widget']['upcoming']['link'][] = $_POST['gig-firstLinkField'];
				$o['widget']['upcoming']['link'][] = $_POST['gig-secondLinkField'];
				update_option('gigs-calendar', $o);
			}
			
			$linkFields = array(
				'city' => 'City',
				'venue' => 'Venue',
				'eventName' => 'Event Name',
			);
			
			?>
				<p>
					<label>
						Widget title:
						<input type="text" size="20" name="gigs_title" value="<?php echo $o['widget']['upcoming']['title']; ?>" />
					</label>
				</p>
				<p>
					<label>
						Number of gigs to show on the sidebar:
						<input type="text" size="5" name="gigs_length" value="<?php echo $o['widget']['upcoming']['length']; ?>" />
					</label>
				</p>
				<p>
					Note: All date formats use the PHP <a href="http://php.net/date">date()</a> function syntax
				</p>
				<p>
					<label>
						Date format for dates in the current year:
						<input type="text" size="5" name="gigs_dateFormat" value="<?php echo $o['widget']['upcoming']['dateFormat']; ?>" />
					</label>
				</p>
				<p>
					<label>
						Date format for dates in a future year:
						<input type="text" size="5" name="gigs_dateFormatYear" value="<?php echo $o['widget']['upcoming']['dateFormatYear']; ?>" />
					</label>
				</p>
				<p>
					<label>
						First piece of data in the link:
						<select name="gig-firstLinkField">
							<?php foreach ( $linkFields as $key => $value ) : ?>
								<option value="<?php echo $key ?>" <?php if ($key == $o['widget']['upcoming']['link'][0]) echo 'selected="selected"' ?>><?php echo $value ?></option>
							<?php endforeach; ?>
						</select>
					</label>
				</p>				
				<p>
					<label>
						Second piece of data in the link:
						<select name="gig-secondLinkField">
							<option value="none">None</option>
							<?php foreach ( $linkFields as $key => $value ) : ?>
								<option value="<?php echo $key ?>" <?php if ($key == $o['widget']['upcoming']['link'][1]) echo 'selected="selected"' ?>><?php echo $value ?></option>
							<?php endforeach; ?>
						</select>
					</label>
				</p>				
			<?php
		}
		
		function init() {
			register_sidebar_widget('Upcoming Gigs', array('dtc_gigs', 'widget_upcoming'));
			register_widget_control('Upcoming Gigs', array('dtc_gigs', 'widget_upcoming_control'), 360, 273);
		}
		
		function upcomingList($args = array()) {
			global $include_folder;
			$o = get_option('gigs-calendar');
			$defaults = array(
				"length" => 5,
				"dateFormat" => 'M j',
				'dateFormatYear' => 'M j, Y',
				'link' => array('city'),
			);
			
			
			$args = array_merge($defaults, $args);
			
			include_once $include_folder . '/classes.php';
			$g = new gig();
			$g->search('`date` >= CURDATE()', '`date` ASC');
			
			$count = 0;
			if ( $g->_count ) : 

				?>
					<ul class="gigs">
						<?php while ( $g->fetch() ) : 
							$v = $g->getVenue(); 
							$p = $g->getPerformances(); 
							$link = array();
							foreach ( $args['link'] as $f ) {
								switch ( $f ) {
									case 'city': 
										$link[] = $v->getCity();
										break;
									case 'venue':
										$link[] = $v->name;
										break;
									case 'eventName':
										$link[] = $g->eventName;
										break;
								}
							}
							$link = array_unique($link);
							foreach ( $link  as $key => $value ) {
								if ( empty($value) ) unset($link[$key]);
							}
							?>
							
							<li><?php echo date((date('Y') == date('Y', strtotime($g->date))) ? $args['dateFormat'] : $args['dateFormatYear'], strtotime($g->date . ' ' . $p->time)) ?>: <a href="<?php echo $g->getPermalink(); ?>">
								<?php echo implode(' - ', $link) ?>
							</a></li>
						<?php if ( ++$count >= $args['length'] ) break; endwhile; ?>
					</ul>
				<?php
			else :
				?>
					<div class="no-gigs"><?php echo $o['no-upcoming']; ?></div>
				<?php
			endif;
		}
		
		function test($posts) {
			global $wp_query;
			
			//print_r($wp_query);
				
			return $posts;
		}
	}
	
	
	$folder = get_bloginfo('wpurl') . '/wp-content/plugins/' . basename(dirname(__FILE__)) . '/';

	add_action('admin_menu', array('dtc_gigs', 'add_admin_page'));

	//add_filter('the_posts', array('dtc_gigs', 'test'));

	add_filter('posts_where', array('dtc_gigs', 'hide_posts'));
	
	add_filter('get_next_post_where', array('dtc_gigs', 'post_nav'));
	add_filter('get_previous_post_where', array('dtc_gigs', 'post_nav'));
	
	add_filter('the_content', array('dtc_gigs', 'display'));
	
	add_action('plugins_loaded', array('dtc_gigs', 'init'));

	if ( get_option('gig_db_version') != DTC_GIGS_DB_VERSION ) {
		dtc_gigs::upgrade();
	}
	
	if ( $_GET['page'] == 'gigs' ) :
		wp_deregister_script('jquery');
		wp_deregister_script('interface');
		wp_deregister_script('jquery-form');
		wp_enqueue_script('jquery', $folder . 'js/jquery.js', array(), '1.2.2.min');
		wp_enqueue_script('jquery-form', $folder . 'js/jquery.form.js', array(), '2.02');
		wp_enqueue_script('interface-partial', $folder . 'js/interface.js', array(), '1.2-partial');
		wp_enqueue_script('jquery-calendar', $folder . 'js/jquery-calendar.js', array(), '2.7');

		add_action('admin_head', array('dtc_gigs', 'admin_css'));
	endif;
	
	add_action('wp_head', array('dtc_gigs', 'display_css'));
else:
	require_once $include_folder . '/ajaxSetup.php';
endif;

?>
